#!/usr/bin/env perl -w

# $Id: t1.t 1 2009-08-31 14:00:42Z stro $

use strict;
use Test;
BEGIN { plan tests => 1 }

use Prompt::Timeout; ok(1);

close(STDIN); # Clear buffer

prompt('# Press <Enter> or wait 1 second', 'DEF', 1);

exit;
